#
# spec file for package ioping
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ioping
Version:        1.3
Release:        bp156.2.5
Summary:        A tool to monitor I/O latency in real time
License:        GPL-3.0-or-later
Group:          System/Benchmark
URL:            https://github.com/koct9i/ioping
Source:         https://github.com/koct9i/ioping/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

%description
A tool to monitor I/O latency in real time. It shows disk latency in the
same way as ping shows network latency.

%prep
%setup -q

%build
%make_build CFLAGS="%{optflags} -std=gnu99"

%install
install -D -p -m 0755 %{name} \
  %{buildroot}%{_bindir}/%{name}
install -D -p -m 0644 %{name}.1 \
  %{buildroot}%{_mandir}/man1/%{name}.1

%files
%license LICENSE
%doc README.md changelog
%{_bindir}/ioping
%{_mandir}/man1/ioping.1%{?ext_man}

%changelog
* Tue Sep 13 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3:
  * Workaround for glibc 2.36 sys/mount.h
  * ioping: add RWF_HIPRI
  * ioping: add "make static"
  * ioping: print notice "slow"/"fast" when twice slower/faster than average
  * ioping: cleanup timing notice
  * ioping: fix mingw build
  * ioping: add option -burst
  * ioping: include stdbool
  * ioping: restore CPPFLAGS in makefile
  * ioping: use 64-bit printf format
  * ioping: switch mingw build to 64-bit and ucrt
  * ioping: retrive device size and name for windows
  * ioping: use F_FULLFSYNC for OSX
  * ioping: move fdatasync after write out of make_request()
  * ioping: implement O_SYNC for windows by FILE_FLAG_WRITE_THROUGH
  * ioping: fallback from non-cached to direct only for reads
  * ioping: rename global target fd variable
  * ioping: add option -e, -entropy for deterministic randomization
  * ioping: add support nowait I/O (RWF_NOWAIT)
  * ioping: print help and version into stdout
  * ioping: add option -I|-time to print current time
  * ioping: describe json format in manpage
  * ioping: add human-readable localtime into json output
* Fri Mar 13 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.2:
  * ioping: add -r, -rate-limit
  * ioping: option -J|-json for printing JSON
  * ioping: add option -a|-warmup
  * ioping: add long options
  * ioping: print filesystem size for file or directory target
  * ioping.1: raw statisitics in nanoseconds
* Fri Mar 24 2017 mpluskal@suse.com
- Update to version 1.0:
  * ioping: update changelog
  * ioping: cleanup statistics
  * ioping: allow fractional values in arguments
  * ioping: print total requests count in raw statistics
  * ioping: ignore first and classify other requests
  * ioping: add read-write mode
  * ioping: add option for speed limit
  * ioping: print total time, speed and count of requests
  * ioping: add mkostemp
  * ioping: add O_SYNC and O_DSYNC modes
  * ioping: call fadvise(RANDOM) for random I/O
  * ioping: remove fdatasync test before oprations
  * Merge pull request #29 from vapier/master
  * Makefile: do not strip while installing
  * Makefile: make it easier to override default optimization settings
  * Makefile: respect CPPFLAGS when compiling
  * ignore generated files
  * ioping: include sys/sysmacros.h for makedev
  * ioping: use xorshift128+ for randomization
  * Makefile: fix mac detection
  * Makefile: no -lrt for mac
  * ioping: no clock_gettime for mac
  * travis-ci: enable osx
  * ioping: link mingw without -lrt
  * ioping: link with -lrt
  * travis-ci: add .travis.yml
  * Makefile: add test target
  * ioping: switch to nanosecond precision
  * Makefile: rename README to README.md
  * Merge branch 'patch-1' of https://github.com/davidak/ioping
  * README.md: update formatting
  * Merge pull request #27 from jgrizou/master
  * Rename README to README.md
  * Update README
  * add link to Nix expression
  * ioping: update changelog
  * ioping: use long long for count of requests
  * ioping: add option -t for detecting cache hits
  * ioping: use cached direct I/O by default if non-cached isn't supported
  * ioping: add windows "overlapped" aio
  * ioping: declare windows have direct I/O
  * ioping: open files with CreateFile on windows
  * ioping: get more randomness on windows
  * ioping: do not override custom interval and deadline by -R
  * Makefile: add top directory into binary archives
  * ioping: keep VERSION right in ioping.c
  * ioping: update help and manpage
  * ioping: update README
  * ioping: fix several integer overflows
  * ioping: handle big requests on linux
  * ioping: always respect explicitly set size
  * ioping: print amount of data written/read
  * ioping: print io run-time instead of real-time
  * ioping: expand all symlinks in device path
* Fri Oct 28 2016 jengelh@inai.de
- Summary fix
* Tue Oct 25 2016 mpluskal@suse.com
- Cleanup spec file
- Update url
- Package based on home:borzz/ioping
